<!-- Scripts -->
<script src="https://code.jquery.com/jquery-3.6.1.min.js" integrity="sha384-i61gTtaoovXtAbKjo903+O55Jkn2+RtzHtvNez+yI49HAASvznhe9sZyjaSHTau9" crossorigin="anonymous"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.5.3/dist/js/bootstrap.bundle.min.js" integrity="sha384-ho+j7jyWK8fNQe+A12Hb8AhRq26LrZ/JpcUGGOn+Y7RsweNrtN/tE3MoK7ZeZDyx" crossorigin="anonymous"></script>
<script src="https://cdn.plot.ly/plotly-2.16.4.min.js" integrity="sha384-usWhKY7pv08CRNu9MTy71U22naQmWGaEKlJuYTlBuMCBWVy7UKwI+6MVgfZvKhhm" crossorigin="anonymous"></script>

<!--TODO: figure out a way not to use github here-->
<script type="text/javascript" src="https://rawgit.com/vitmalina/w2ui/master/dist/w2ui.js"></script>

<script>
{% include 'js/common.js' %}
{% include 'js/data.js' %}
{% include 'js/graphs.js' %}
{% include 'js/tables.js' %}
{% include 'js/texts.js' %}
</script>
